@@ -9,7 +9,7 @@ use Moo;
 #use Perinci::Object;
 use Perinci::ToUtil;
 
-our $VERSION = '0.53'; # VERSION
+our $VERSION = '0.54'; # VERSION
 
 with 'Perinci::To::Text::AddDocLinesRole';
 with 'SHARYANTO::Role::Doc::Section';
@@ -928,7 +928,7 @@ Perinci::CmdLine - Rinci/Riap-based command-line application framework
 
 =head1 VERSION
 
-version 0.53
+version 0.54
 
 =head1 SYNOPSIS
 
@@ -995,6 +995,14 @@ What you'll get:
 
 =item * Command-line options parsing
 
+Non-scalar arguments (array, hash, other nested) can also be passed as JSON or
+YAML (both will be attempted). For example, the C<tags> argument is defined as
+'array':
+
+ % mycmd --tags '[foo, bar, baz]' ; # interpreted as YAML
+ % mycmd --tags '["foo","bar"]'   ; # interpreted as JSON
+ % mycmd --tags '[foo, bar, baz'  ; # fails both
+
 =item * Help message (utilizing information from metadata, supports translation)
 
 =item * Tab completion for bash (including completion from remote code)
@@ -1169,29 +1177,35 @@ the default C<less> or C<more>.
 
 =head2 How does Perinci::CmdLine compare with other CLI-app frameworks?
 
-Perinci::CmdLine is part of a more general metadata and wrapping framework
-(Perinci::* modules family). Aside from a command-line application, your
-metadata is also usable for other purposes, like providing access over HTTP/TCP,
-documentation, etc.
+The most important difference is that Perinci::CmdLine accesses your code
+through L<Riap> protocol, not directly. This means that aside from local Perl
+code, Perinci::CmdLine can also provide CLI for code in remote hosts/languages.
+For a very rough demo, download and run this PHP Riap::TCP server
+https://github.com/sharyanto/php-Phinci/blob/master/demo/phi-tcpserve-terbilang.php
+on your system. After that, try running:
 
-Configuration file support is missing (coming soon, most probably will be based
-on L<Config::Ini::OnDrugs>).
+ % peri-run riap+tcp://localhost:9090/terbilang --help
+ % peri-run riap+tcp://localhost:9090/terbilang 1234
 
-Also lacking is more documentation and more plugins.
+Everything from help message, calling, argument checking, tab completion works
+for remote code as well as local Perl code.
 
-=head2 Why is nonscalar arguments parsed as YAML instead of JSON/etc?
+Aside from this difference, there are several others:
 
-I think YAML is nicer in command-line because quotes are optional in a few
-places:
+=over 4
 
- $ cmd --array '[a, b, c]' --hash '{foo: bar}'
+=item * Non-OO, function-centric
 
-versus:
+If you want OO, there are already several frameworks out there for you, e.g.
+L<App::Cmd>, L<App::Rad>, L<MooX::Cmd>, etc.
 
- $ cmd --array '["a","b","c"]' --hash '{"foo":"bar"}'
+=item * Configuration file support is currently missing
 
-Though YAML requires spaces in some places where JSON does not. A flag to parse
-as JSON can be added upon request.
+Coming soon, most probably will be based on L<Config::Ini::OnDrugs>.
+
+=item * Also lacking is more documentation and more plugins
+
+=back
 
 =head2 How to add support for new output format (e.g. XML, HTML)?
 
